OC.L10N.register(
    "core",
    {
    "Please select a file." : "Seleccionatz un fichièr.",
    "File is too big" : "Fichièr tròp pesuc",
    "The selected file is not an image." : "Lo fichièr seleccionat es pas un imatge.",
    "The selected file cannot be read." : "Se pòt pas legir lo fichièr seleccionat.",
    "The file was uploaded" : "Lo fichièr es estat enviat",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Lo fichièr enviat despassa la directiva upload_max_filesize de php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Lo fichièr enviat despassa la directiva MAX_FILE_SIZE especificada dins lo formulari HTML",
    "The file was only partially uploaded" : "Lo fichièr es estat parcialament enviat",
    "No file was uploaded" : "Cap de fichièr pas enviat",
    "Missing a temporary folder" : "Dossièr temporari absent",
    "Could not write file to disk" : "Escritura impossibla al disc",
    "A PHP extension stopped the file upload" : "Una extension PHP a arrestat lo mandadís de fichièr",
    "Invalid file provided" : "Fichièr fornit invalid",
    "No image or file provided" : "Cap d’imatge o fichièr fornit",
    "Unknown filetype" : "Tipe de fichièr desconegut",
    "An error occurred. Please contact your admin." : "Una error s’es producha. Volgatz ben contactar l’admin.",
    "Invalid image" : "Imatge desconegut",
    "No temporary profile picture available, try again" : "Cap d’imatge de perfil temporari pas disponible, tornatz ensajar",
    "No crop data provided" : "Cap de donada de produccion",
    "No valid crop data provided" : "Cap de donada pas valida pas provesida",
    "Crop is not square" : "Lo retalhatge es pas carrat",
    "State token does not match" : "Lo geton d’estat correspond pas",
    "Invalid app password" : "Senhal d’aplicacion invalid",
    "Could not complete login" : "Autocomplecion impossibla de l’identificant",
    "Your login token is invalid or has expired" : "Lo geton es siá invalid siá expirat",
    "Login" : "Login",
    "Password reset is disabled" : "Reïnicializacion del senhal desactivada",
    "Could not reset password because the token is expired" : "Reïnicializacion del senhal impossibla pr’amor que lo geton a expirat",
    "Could not reset password because the token is invalid" : "Reïnicializacion del senhal impossibla pr’amor que lo geton es invalid",
    "%s password reset" : "reïnicializar lo senhal de %s",
    "Password reset" : "Reïnicializacion de senhal",
    "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "Clicat sul boton seguent per reïnicializar vòstre senhal. S’avètz pas demandat sa reïnicializacion, ignoratz aqueste corrièl.",
    "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "Clicat sul ligam seguent per reïnicializar vòstre senhal. S’avètz pas demandat sa reïnicializacion, ignoratz aqueste corrièl.",
    "Reset your password" : "Reïnicializatz vòstre senhal",
    "Nextcloud Server" : "Servidor Nextcloud",
    "Some of your link shares have been removed" : "D’unes de vòstres ligams de partiment foguèron tirats",
    "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "A causa d’una avaria de seguretat nos calguèt tirar certans de vòstres ligams de partiment. Vejatz lo ligam per mai d’informacions.",
    "Learn more ↗" : "Ne saber mai ↗",
    "Preparing update" : "Preparacion de la mesa a jorn",
    "[%d / %d]: %s" : "[%d / %d] : %s",
    "Repair step:" : "Etapa de reparacion :",
    "Repair info:" : "Info de reparacion :",
    "Repair warning:" : "Avertiment de reparacion :",
    "Repair error:" : "Error de reparacion :",
    "Turned on maintenance mode" : "Mòde manteniment aviat",
    "Turned off maintenance mode" : "Mòde manteniment atudat",
    "Maintenance mode is kept active" : "Lo mòde manteniment ten d’èsser actiu",
    "Updating database schema" : "Actualizacion de l’esquèma de la basa de donadas",
    "Updated database" : "Basa de donada mesa a jorn",
    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Verificacion se l’esquèma de la basa de donadas per %s pòt èsser actualizat (aquò pòt trigar segon la talha de basa de donadas)",
    "Updated \"%1$s\" to %2$s" : "« %1$s » mes a jorn a %2$s",
    "Set log level to debug" : "Definir lo nivèl de jornal d’audit al nivèl debugatge",
    "Reset log level" : "Restablir nivèl de jornals",
    "Starting code integrity check" : "Debuta de la verificacion d’integritat del còdi",
    "Finished code integrity check" : "Cerificacion d’integritat del còdi acabada",
    "%s (incompatible)" : "%s (incompatible)",
    "The following apps have been disabled: %s" : "Las aplicacions seguentas son estadas desactivadas : %s",
    "Already up to date" : "Ja a jorn",
    "Error occurred while checking server setup" : "Error producha pendent la verificacion de l’installacion del servidor",
    "unknown text" : "tèxt desconegut",
    "Hello world!" : "Adieu monde !",
    "sunny" : "ensolelhat",
    "Hello {name}, the weather is {weather}" : "Adiu {name}, lo temps es {weather}",
    "Hello {name}" : "Adiu {name}",
    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Vaquí vòstres resultats de recèrca<script>alert(1)</script></strong>",
    "new" : "nòu",
    "_download %n file_::_download %n files_" : ["telecargar %n fichièr","telecargar %n fichièrs"],
    "The update is in progress, leaving this page might interrupt the process in some environments." : "La mesa a jorn es en cors, quitar aquesta pagina poiriá interrompre lo processús dins d’unes environaments.",
    "Update to {version}" : "Metre a jorn a {version}",
    "An error occurred." : "Una error s’es producha.",
    "Please reload the page." : "Volgatz recargar la pagina.",
    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "La mesa a jorn a pas reüssit. Mai mai d’informacions <a href=\"{url}\">visitatz nòstra publicacion al forum</a> que tracta d’aqueste problèma.",
    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "La mesa a jorn a pas reüssit. Mercés de senhalar aqueste problèma a la <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Comunautat Nexcloud</a>.",
    "Continue to {productName}" : "Contunhar cap a {productName}",
    "More apps" : "Mai d’aplicacions",
    "Currently open" : "Actualament dobèrta",
    "_{count} notification_::_{count} notifications_" : ["{count} notificacion","{count} notificacions"],
    "No" : "No",
    "Yes" : "Yes",
    "Log in" : "Connexion",
    "Logging in …" : "Identificacion…",
    "Server side authentication failed!" : "Autentificacion costat servidor fracassada !",
    "Please contact your administrator." : "Mercés de contactar vòstre administrator.",
    "An internal error occurred." : "Una error intèrna s’es producha.",
    "Please try again or contact your administrator." : "Tornatz ensajar o contactatz vòstre administrator.",
    "Password" : "Senhal",
    "Log in to {productName}" : "Se connectar a {productName}",
    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Avèm detectat mantun ensag invalid de connexion a partir de vòstra IP. Per consequent vòstra connexion venenta serà en pausa per 30 segondas.",
    "Account name or email" : "Nom d’utilizaire o email",
    "Log in with a device" : "Connexion amb un periferic",
    "Your account is not setup for passwordless login." : "Vòstre compte es pas parametrat per una autentificacion sens senhal.",
    "Browser not supported" : "Navegador pas pres en carga",
    "Passwordless authentication is not supported in your browser." : "L’autentificacion sens senhal es pas presa en cargar per vòstre navegador.",
    "Your connection is not secure" : "Vòstra connexion es pas segura",
    "Passwordless authentication is only available over a secure connection." : "L’autentificacion sens senhal es sonque disponibla via una connexion segura.",
    "Reset password" : "Reïnicializar senhal",
    "Couldn't send reset email. Please contact your administrator." : "Impossible de mandar lo corrièl de reïnicializacion. Contactatz vòstre administrator.",
    "Password cannot be changed. Please contact your administrator." : "Se pòt pas cambiar lo senhal. Mercés de contactar vòstre administrator.",
    "Back to login" : "Tornar a la connexion",
    "New password" : "Senhal novèl",
    "I know what I'm doing" : "Sabi çò que fau",
    "Resetting password" : "Reïnicializacion de senhal",
    "Recommended apps" : "Aplicacions recomandadas",
    "Loading apps …" : "Cargament aplicacions…",
    "Installing apps …" : "Installacion aplicacions…",
    "App download or installation failed" : "Telecargament o installacion de l’aplicacion fracassada",
    "Cannot install this app because it is not compatible" : "Impossibla d’installar aquesta app perque es pas compatibla",
    "Cannot install this app" : "Impossible d’installar aquesta app",
    "Skip" : "Sautar",
    "Install recommended apps" : "Installar las aplicacions recomandadas",
    "Schedule work & meetings, synced with all your devices." : "Planificatz prètzfaches e reünions, sincronizats amb totes vòstres periferics.",
    "Keep your colleagues and friends in one place without leaking their private info." : "Gardatz vòstres companhs e amics a un sòl lòc sens divulgar lor vida privada.",
    "Simple email app nicely integrated with Files, Contacts and Calendar." : "Aplicacion simpla e simpatica de corrièl integrada a Fichièrs, Contactes e Calendièr.",
    "Search contacts" : "Cercar pels contactes",
    "Reset search" : "Escafar la recèrca",
    "Search contacts …" : "Cercar pels contactes…",
    "Could not load your contacts" : "Cargament impossible de vòstres contactes",
    "No contacts found" : "Cap de contact pas trobat",
    "Install the Contacts app" : "Installar l’aplicacion Contactes",
    "Loading your contacts …" : "Cargaments dels contactes…",
    "Looking for {term} …" : "Recèrca de {term}…",
    "Search for {name} only" : "Cercar sonque {name}",
    "Start typing to search" : "Començatz de picar per recercar",
    "Loading more results …" : "Cargament de mai de resultats…",
    "Load more results" : "Cargar mai de resultats",
    "Search" : "Recercar",
    "No results for {query}" : "Cap de resultat per {query}",
    "An error occurred while searching for {type}" : "Una error s’es producha en cercant {type}",
    "Forgot password?" : "Senhal oblidat ?",
    "Back" : "Retorn",
    "Login form is disabled." : "Lo formulari de connexion es desactivat.",
    "Edit Profile" : "Modificar perfil",
    "Search {types} …" : "Recèrca {types}…",
    "Date" : "Data",
    "Today" : "Uèi",
    "People" : "Gent",
    "Searching …" : "Recèrca…",
    "This browser is not supported" : "Aqueste navigador es pas pres en carga",
    "Supported versions" : "Versions presas en carga",
    "{name} version {version} and above" : "{name} version {version} e ulterior",
    "Settings menu" : "Menú paramètres",
    "Choose" : "Causir",
    "Copy" : "Copiar",
    "Move" : "Move",
    "OK" : "D'acòrdi",
    "read-only" : "lectura-sola",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count} conflicte de fichièr","{count} conflictes de fichièr"],
    "One file conflict" : "Un conflicte de fichièr",
    "New Files" : "Fichièrs novèls",
    "Already existing files" : "Fichièrs ja existents",
    "Which files do you want to keep?" : "Quines fichièrs volètz gardar ?",
    "If you select both versions, the copied file will have a number added to its name." : "Se seleccionatz las doas versions, lo fichièr copiat aurà un nombre apondut al seu nom.",
    "Cancel" : "Anullar",
    "Continue" : "Contunhar",
    "(all selected)" : "(totes seleccionats)",
    "({count} selected)" : "({count} seleccionats)",
    "Saving …" : "Enregistrament…",
    "seconds ago" : "fa qualques segondas",
    "Connection to server lost" : "Connexion al servidor perduda",
    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Problèma de cargar de la pagina, actualizacion d’aquí %n seconda","Problèma de cargar de la pagina, actualizacion d’aquí %n secondas"],
    "Add to a project" : "Ajustar a un projècte",
    "Show details" : "Mostrar detalhs",
    "Hide details" : "Amagar detalhs",
    "Rename project" : "Renomenar lo projècte",
    "Failed to rename the project" : "Renomenatge impossible del projècte",
    "Failed to create a project" : "Creacion d’un projècte fracassada",
    "Failed to add the item to the project" : "Apondon fracassat d’un element al projècte",
    "Connect items to a project to make them easier to find" : "Connectatz d’elements a un projècte per lo rendre mai simples de trobar",
    "New in" : "Nòu dins",
    "View changelog" : "Veire jornal de modificacions",
    "Very weak password" : "Senhal plan feble",
    "Weak password" : "Senhal feble",
    "So-so password" : "Senhal mejan",
    "Good password" : "Bon senhal",
    "Strong password" : "Senhal fòrt",
    "No action available" : "Cap d’accion pas disponibla",
    "Error fetching contact actions" : "Error en recuperacion las accions contacte",
    "Non-existing tag #{tag}" : "Etiqueta inexistenta #{tag}",
    "Restricted" : "Restrencha",
    "Invisible" : "Invisible",
    "Delete" : "Suprimir",
    "Rename" : "Renomenar",
    "Collaborative tags" : "Etiquetas collaborativas",
    "No tags found" : "Cap d’etiqueta pas trobada",
    "Personal" : "Personal",
    "Apps" : "Aplicacions",
    "Admin" : "Admin",
    "Help" : "Ajuda",
    "Access forbidden" : "Accès defendut",
    "Profile not found" : "Perfil pas trobat",
    "The profile does not exist." : "Lo perfil existís pas.",
    "Back to %s" : "Tornar a %s",
    "Page not found" : "Pagina pas trobada",
    "Too many requests" : "Tròp de requèstas",
    "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "I a agut tròp de requèstas a partir de vòstre ret. Tornatz ensajar mai tard o contactatz vòstre administrator s’aquò es una error.",
    "Error" : "Error",
    "Previous" : "Precedent",
    "Internal Server Error" : "Error intèrna del servidor",
    "The server was unable to complete your request." : "Lo servidor a pas pogut terminar vòstra requèsta.",
    "If this happens again, please send the technical details below to the server administrator." : "S’aquò tòrna arribar, enviatz lo detalhs tecnics çai-jos a l’administrator del servidor.",
    "More details can be found in the server log." : "Mai de detalhs se tròban als jornals d’audit del servidor.",
    "Technical details" : "Detalhs tecnics",
    "Remote Address: %s" : "Adreça distanta : %s",
    "Request ID: %s" : "ID requèsta : %s",
    "Type: %s" : "Tipe : %s",
    "Code: %s" : "Còdi : %s",
    "Message: %s" : "Messatge : %s",
    "File: %s" : "Fichièr : %s",
    "Line: %s" : "Linha : %s",
    "Trace" : "Traça",
    "Security warning" : "Avertiment de seguretat",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Vòstre repertòri de donadas e vòstres fichièrs son probablament accessibles a partir d’internet pr’amor que lo fichièr .htaccess fonciona pas.",
    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Per d’informacions per corrèctament configurar vòstre servidor, consultatz la <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentacion</a>.",
    "Create an <strong>admin account</strong>" : "Crear un <strong>compte admin</strong>",
    "Show password" : "Mostrar lo senhal",
    "Toggle password visibility" : "Alternar la visibilitat del senhal",
    "Storage & database" : "Emmagazinatge & basa de donada",
    "Data folder" : "Dossièr de donadas",
    "Configure the database" : "Configurar la basa de donadas",
    "Only %s is available." : "Sonque %s es disponible.",
    "Install and activate additional PHP modules to choose other database types." : "Installatz e activatz los modules PHP complementaris per causir d’autres tipes de basas de donadas.",
    "For more details check out the documentation." : "Per mai de detalhs consultatz la documentacion.",
    "Database password" : "Senhal basa de donadas",
    "Database name" : "Nom basa de donadas",
    "Database tablespace" : "Tablespace basa de donadas",
    "Database host" : "Òste basa de donadas",
    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Volgatz especificar lo numèro de pòrt aprèp lo nom d’òste (ex : localhost:5432).",
    "Performance warning" : "Avertiment de performança",
    "You chose SQLite as database." : "Causissètz SQLite coma basa de donadas.",
    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite deu solament èsser utilizat per d’instàncias minimalas e de desvolopament. Per la produccion recomandam un autre sistèma de basa de donadas.",
    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "S’utilizatz los clients per sincronizar de fichièrs, l’utilizacion de SQLite es forçadament descoratjada.",
    "Install" : "Installar",
    "Installing …" : "Installacion...",
    "Need help?" : "Besonh d’ajuda ?",
    "See the documentation" : "Vejatz la documentacion",
    "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue." : "Sembla que sètz a reïnstallar vòstre Nextcloud. Pasmens lo fichièr CAN_INSTALL es absent del repertòri config. Volgatz ben crear lo fichièr CAN_INSTALL dins vòstre dossièr config per contunhar.",
    "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "Supression impossibla de CAN_INSTALL dins lo repertòri config. Mercés de lo tirar manualament.",
    "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Aquesta aplicacion requerís JavaScript per foncionar coma cal. {linkstart}Activatz JavaScript{linkend} e recargatz la pagina.",
    "Skip to main content" : "Sautar al contengut principal",
    "Skip to navigation of app" : "Passar a la navegacion d’aplications",
    "Go to %s" : "Anar a %s",
    "Get your own free account" : "Obtenètz vòstre pròpri compte gratuit",
    "Connect to your account" : "Connectatz-vos a vòstre compte",
    "Please log in before granting %1$s access to your %2$s account." : "Autentificatz-vos abans de donnar l’accès a %1$s a vòstre compte %2$s.",
    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Se ensajatz pas de configurar un periferic novèl o una aplicacion novèla, qualqu’un ensaja de vos far donar accès a vòstras donadas. En aqueste cas, contunhetz pas e contactatz vòstre administrator sistèma.",
    "Grant access" : "Donar accès",
    "Account access" : "Accès compte",
    "Currently logged in as %1$s (%2$s)." : "Actualament connectat coma %1$s (%2$s).",
    "You are about to grant %1$s access to your %2$s account." : "Sètz a mand de donar accès a vòstra compte %2$s a %1$s.",
    "Account connected" : "Compte connectat",
    "Your client should now be connected!" : "Vòstre client deu èsser connectat ara !",
    "You can close this window." : "Podètz tampar aquesta fenèstra.",
    "This share is password-protected" : "Aqueste partiment es protegit per un senhal",
    "Email address" : "Adreça mail",
    "Password sent!" : "Senhal enviat !",
    "You are not authorized to request a password for this share" : "Sètz pas autorizat a demandar un senhal per aqueste partiment",
    "Two-factor authentication" : "Autentificacion dos factors",
    "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "La seguretat renfortida es activada per vòstre compte. Causissètz un segond factor per l’autentificacion :",
    "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "Cargament impossible d’almens un metòde d’autentificacion dos factors. Contactatz vòstre admin.",
    "Set up two-factor authentication" : "Configurar l’autentificacion dos factors",
    "Use backup code" : "Utilizar còde de recuperacion",
    "Cancel login" : "Anullar connexion",
    "Enhanced security is enforced for your account. Choose which provider to set up:" : "La seguretat renfortida es aplicada a vòstre compte. Causissètz un provesidor de configurar :",
    "Error while validating your second factor" : "Error pendent la validacion del segond factor",
    "Access through untrusted domain" : "Accès via un domeni pas fisable",
    "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "Contactatz vòstre administrator. Se ne sètz un, modificatz lo paramètre « trusted_domains » dins config/config.php coma l’exemple dins config.sample.php.",
    "Further information how to configure this can be found in the %1$sdocumentation%2$s." : "Per mai d’informacions per configurar aquò consultatz la %1$sdocumentacion%2$s.",
    "App update required" : "Mesa a jorn d’aplicacion requerida",
    "%1$s will be updated to version %2$s" : "%1$s serà passat a la version %2$s",
    "The following apps will be updated:" : "Las aplicacions seguentas seràn mesas a jorn :",
    "These incompatible apps will be disabled:" : "Aquestas aplicacions incompatiblas seràn desactivadas :",
    "The theme %s has been disabled." : "Lo tèma %s es estat desactivat.",
    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Asseguratz-vos que la basa de donadas, lo dossièr config e lo dossièr de donadas « data » foguèron salvagardats abans de contunhar.",
    "Start update" : "Començar la mesa a jorn",
    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Per evitar qu’expire lo temps d’espèra amb de bravas installacions, podètz a la plaça executar la comanda seguentas a partir del repertòri d’installacion :",
    "Detailed logs" : "Jornals detalhats",
    "Update needed" : "Mesa a jorn requerida",
    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "Per d’ajuda, vejatz la <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentacion</a>.",
    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Sabi que se contunhi la mesa a jorn via l’interfàcia web i a un risc, que la requèsta s’execute e despasse lo delai e poiriá causar una pèrda de donadas, mas ai una salvagarda de seguretat e sabi cossí restaurar mon instància en cas de fracàs.",
    "Upgrade via web on my own risk" : "Accèpti lo risc de metre a nivèl",
    "Maintenance mode" : "Mòde manteniment",
    "This %s instance is currently in maintenance mode, which may take a while." : "L’instància %s es actualament en mòde manteniment, pòt trigar.",
    "This page will refresh itself when the instance is available again." : "Aquesta pagina s’actualizarà soleta quand l’instància serà disponibla de nòu.",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "Contactatz l’administrator sistèma s’aqueste messatge ten d’aparéisser o apareis sens rason.",
    "The user limit of this instance is reached." : "Lo limit d’utilizaires d’aquesta instància es atengut.",
    "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "Sembla que vòstre servidor es pas configurat corrèctament per permetre la sincronizacion de fichièrs, perque l’interfàcia WebDAV sembla copada.",
    "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "PHP sembla corrèctament configurat per interpretar las variablas d’environament del sistèma. La pròva amb getenv(\"PATH\") a pas tornar una responda voida.",
    "The read-only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "La configuracion lectura-sola es estada activada. Aquò empacha de configurar d’unes paramètres via l’interfàcia web. Pasmens, òm deu far venir lo fichièr modificable manualament per cada mesa a jorn.",
    "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "Vòstra basa de donada s’executa pas amb la transaccion de nivèl d’isolacion « READ COMMITTED ». Aquò pòt causar problèmas quand mantuna accion s’executan en parallèl.",
    "The PHP module \"fileinfo\" is missing. It is strongly recommended to enable this module to get the best results with MIME type detection." : "Manca lo module « fileinfo » de PHP. Se recomanda d’activar aqueste modul per obténer los melhors resultats amb la deteccion de tipe MIME.",
    "Your installation has no default phone region set. This is required to validate phone numbers in the profile settings without a country code. To allow numbers without a country code, please add \"default_phone_region\" with the respective {linkstart}ISO 3166-1 code ↗{linkend} of the region to your config file." : "Vòstra installacion a pas cap de de region telefonica per defaut. Aquò es requerit per validar lo numèros de telefòn als paramètres de perfil sens còdi país. Per autorizar los numèros sens còdi país, apondètz « default_phone_region » amb lo {linkstart}còdi ISO 3166-1↗{linkend}  correspondent de la region dins vòstre fichièr config.",
    "It was not possible to execute the cron job via CLI. The following technical errors have appeared:" : "Èra pas possible d’executar lo prètzfach cron via CLI. Las errors tecnicas seguentas an aparegut :",
    "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "La foncion « set_time_limit\" » es pas disponibla. Aquò poiriá menar a una execucion copada al mièg camin, e a una copadura de l’installacion. L’activacion d’aquesta foncion es forçadament recomandada.",
    "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "Vòstre PHP prend pas en carga FreeType, çò que causa lo rompement dels imatges de perfil e de l’interfàcia de paramètres.",
    "Missing index \"{indexName}\" in table \"{tableName}\"." : "Indèx absent « {indexName} » dins la taula « {tableName} ».",
    "Missing primary key on table \"{tableName}\"." : "Manca la clau primària de la taula « {tableName} ».",
    "Missing optional column \"{columnName}\" in table \"{tableName}\"." : "Manca la colomna opcionala « {columnName} » a la taula « {tableName} ».",
    "This instance is missing some recommended PHP modules. For improved performance and better compatibility it is highly recommended to install them." : "Mancan d’unes modules PHP recomandats a aquesta instància. Per de melhoras performanças e una melhora compatibilitat es forçadament recomandat de los installar.",
    "Module php-imagick in this instance has no SVG support. For better compatibility it is recommended to install it." : "Lo module php-imagick d’aquesta instància a pas cap de compatibilitat SVG. Es forçadament recomandant de l’installar per una melhora compatibilitat.",
    "SQLite is currently being used as the backend database. For larger installations we recommend that you switch to a different database backend." : "SQLite es actualament utilizat per la basa de donadas. Per d’installacions mai grandas vos recomandam de bascular sus un autre gestionari de basa de donadas.",
    "This is particularly recommended when using the desktop client for file synchronisation." : "Es particularament recomandat pendent l’utilizacion de client burèu per la sincronizacion de fichièrs.",
    "The PHP memory limit is below the recommended value of 512MB." : "La memòria limit PHP es jos la valor recomandada de 512 Mo.",
    "Some app directories are owned by a different user than the web server one. This may be the case if apps have been installed manually. Check the permissions of the following app directories:" : "D’unes repertòris d’aplicacion son la proprietat d’un utilizaire diferent qu’aquel del servidor web. Aquò pòt èsser lo cas se las aplicacions foguèron installadas manualament. Verificatz las permission dels repertòris d’aplicacion seguents :",
    "The \"{header}\" HTTP header is not set to \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "L’entèsta HTTP « {header} » es pas definida a « {expected} ». Aquò es un risc de seguretat o de vida privada, es recomandat d’ajustar aqueste paramètre en consequéncia.",
    "The \"{header}\" HTTP header is not set to \"{expected}\". Some features might not work correctly, as it is recommended to adjust this setting accordingly." : "L’entèsta HTTP « {header} » es pas definida a « {expected} ». D’unas foncionalitats poirián foncionar pas corrèctament, es recomandat d’ajustar aqueste paramètre en consequéncia.",
    "Wrong username or password." : "Marrit nom d’utilizaire o senhal.",
    "User disabled" : "Utilizaire desactivat",
    "Username or email" : "Nom d’utilizaire o senhal",
    "Start search" : "Aviar la recèrca",
    "Open settings menu" : "Dobrir lo menú de paramètres",
    "Settings" : "Paramètres",
    "Avatar of {fullName}" : "Avatar de {fullName}",
    "Show all contacts …" : "Mostrar totes los contactes…",
    "No files in here" : "Cap de fichièr aicí",
    "New folder" : "Novèl dorsièr",
    "No more subfolders in here" : "Cap de jos-dossièr aicí",
    "Name" : "Nom",
    "Size" : "Talha",
    "Modified" : "Modificat",
    "\"{name}\" is an invalid file name." : "\"{name}\" es pas un nom de fichièr valid.",
    "File name cannot be empty." : "Lo nom de fichièr pòt pas èsser void.",
    "\"/\" is not allowed inside a file name." : "« / » es pas permés dins un nom de fichièr.",
    "\"{name}\" is not an allowed filetype" : "« {name} » es pas un tipe de fichièr permés",
    "{newName} already exists" : "{newName} existís ja",
    "Error loading file picker template: {error}" : "Error de cargament del modèl del selector de fichièr : {error}",
    "Error loading message template: {error}" : "Error de cargament del modèl de messatge : {error}",
    "Show list view" : "Afichar la vista en lista",
    "Show grid view" : "Afichar la vista en grasilha",
    "Pending" : "En espèra",
    "Home" : "Domicili",
    "Copy to {folder}" : "Copiar a {folder}",
    "Move to {folder}" : "Desplaçar a {folder}",
    "Authentication required" : "Autentificacion requerida",
    "This action requires you to confirm your password" : "Aquesta accions vos demanda de confirmar vòstre senhal",
    "Confirm" : "Confirmar",
    "Failed to authenticate, try again" : "Autentificacion pas reüssida, tornatz ensajar",
    "Users" : "Utilizaires",
    "Username" : "Nom d'utilizaire",
    "Database user" : "Utilizaire basa de donadas",
    "Confirm your password" : "Confirmatz lo senhal",
    "App token" : "Geton aplicacion",
    "Alternative log in using app token" : "Autentificacion alternativa en utilizant un geton d’aplicacion",
    "Please use the command line updater because you have a big instance with more than 50 users." : "Mercés d’utilizar l’aisina de mesa a jorn en linha de comanda s’avètz una brava instància de mai de 50 utilizaires."
},
"nplurals=2; plural=(n > 1);");
